##  External Content
You can restrict URLs that users can embed in the External Content dashboard panel. By default, any URL can be embedded. Adjusting these settings is especially relevant when embedding content from third-party systems such as BI tools.
  * To block specific URLs, in the External Content settings group, deselect the Do not restrict external content checkbox, then enter URLs to be blocked in the Restrict external content to box.
  * To allow embedding any URLs, select the Do not restrict external content checkbox.


You can also decide whether you want to allow pop-ups, form submissions, and iframe elements from external URLs by using the appropriate checkboxes.
**Tip**
When embedding content from external systems, such as business intelligence tools, into dashboards, configure the appropriate settings to publish content externally without making it available to everyone.
